/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { createStore } from 'zustand/vanilla';
import { useStore } from 'zustand';
/**
 * Iterate over all cells map and check if all cells/sessions are ready
 */
const areAllKernelSessionsAvailable = (cells) => {
    for (const cell of cells.values()) {
        if (!cell.isKernelSessionAvailable) {
            return false;
        }
    }
    return true;
};
export const cellStore = createStore((set, get) => ({
    cells: new Map(),
    source: '',
    outputsCount: 0,
    isKernelSessionAvailable: false,
    areAllKernelSessionsReady: false,
    adapter: undefined,
    setCells: (cells) => set((cell) => ({ cells })),
    setSource: (id, source) => {
        const cells = get().cells;
        const cell = cells.get(id);
        if (cell) {
            cell.source = source;
        }
        else {
            cells.set(id, { source });
        }
        set((cell) => ({ cells }));
    },
    setOutputsCount: (id, outputsCount) => {
        const cells = get().cells;
        const cell = cells.get(id);
        if (cell) {
            cell.outputsCount = outputsCount;
        }
        else {
            cells.set(id, { outputsCount });
        }
        set((state) => ({ cells }));
    },
    setIsKernelSessionAvailable: (id, isKernelSessionAvailable) => {
        const cells = get().cells;
        const cell = cells.get(id);
        if (cell) {
            cell.isKernelSessionAvailable = isKernelSessionAvailable;
        }
        else {
            cells.set(id, { isKernelSessionAvailable });
        }
        const areAllKernelSessionsReady = areAllKernelSessionsAvailable(cells);
        set((cell) => ({ cells, areAllKernelSessionsReady }));
    },
    setAdapter: (id, adapter) => {
        const cells = get().cells;
        const cell = cells.get(id);
        if (cell) {
            cell.adapter = adapter;
        }
        else {
            cells.set(id, { adapter });
        }
        set((cell) => ({ cells }));
    },
    getAdapter: (id) => {
        return get().cells.get(id)?.adapter;
    },
    getSource: (id) => {
        return get().cells.get(id)?.source;
    },
    getOutputsCount: (id) => {
        return get().cells.get(id)?.outputsCount;
    },
    getIsKernelSessionAvailable: (id) => {
        return get().cells.get(id)?.isKernelSessionAvailable;
    },
    execute: (id) => {
        const cells = get().cells;
        const cell = cells.get(id);
        if (cell) {
            cell.adapter?.execute();
        }
        else {
            get().cells.forEach((cell) => cell.adapter?.execute());
        }
    },
}));
export function useCellStore(selector) {
    return useStore(cellStore, selector);
}
export default useCellStore;
//# sourceMappingURL=CellState.js.map